# napolipy

Napoli Unicode Logo generator

**NOTE**: Not affiliated with [Società Sportiva Calcio Napoli](https://sscnapoli.it)

The original logo is distributed following the directions of the [Creative Commons license v4.0](https://creativecommons.org/licenses/by/4.0/)

## Installation

### From github

```python
git clone https://github.com/TheDarkBug/napolipy.git
pip install ./napolipy
```

### From PyPI

[PyPI page](https://pypi.org/project/napolipy/)

```shell
python -m pip install napolipy
```
